@@ -17,7 +17,7 @@
  */
 
 #define NL_MAJOR 1
-#define NL_MINOR 0
-#define NL_REV   9
-#define NL_DATE  "Jun 21, 2002"
-#define VERSION  "1.0.9"
+#define NL_MINOR 2
+#define NL_REV   2
+#define NL_DATE  "Jul 24, 2002"
+#define VERSION  "1.2.2"
